@@ -119,9 +119,10 @@ ft_t ft;
 		return(ST_EOF);
 	}
 	st_readdw(ft, &totalsize);
-	if (st_reads(ft, buf, 4) == ST_EOF || strncmp(buf, "AIFF", 4) != 0)
+	if (st_reads(ft, buf, 4) == ST_EOF || (strncmp(buf, "AIFF", 4) != 0 && 
+	    strncmp(buf, "AIFC", 4) != 0))
 	{
-		st_fail("AIFF 'FORM' chunk does not specify 'AIFF' as type");
+		st_fail("AIFF 'FORM' chunk does not specify 'AIFF' or 'AIFC' as type");
 		return(ST_EOF);
 	}
 
@@ -142,15 +143,24 @@ ft_t ft;
 		if (strncmp(buf, "COMM", 4) == 0) {
 			/* COMM chunk */
 			st_readdw(ft, &chunksize);
-			if (chunksize != 18)
-			{
-				st_fail("AIFF COMM chunk has bad size");
-				return(ST_EOF);
-			}
 			st_readw(ft, &channels);
 			st_readdw(ft, &frames);
 			st_readw(ft, &bits);
 			rate = read_ieee_extended(ft);
+			chunksize -= 18;
+			if (chunksize > 0)
+			{
+			    st_reads(ft, buf, 4);
+			    chunksize -= 4;
+			    if (strncmp(buf, "NONE", 4) != 0)
+			    {
+				buf[4] = 0;
+				st_fail("Can not support AIFC files that contain compressed data: %s",buf);
+				return(ST_EOF);
+			    }
+			}
+			while(chunksize-- > 0)
+			    st_readb(ft, (unsigned char *)&trash);
 			foundcomm = 1;
 		}
 		else if (strncmp(buf, "SSND", 4) == 0) {
@@ -225,11 +235,12 @@ ft_t ft;
 			st_readw(ft, &releaseLoopBegin);  /* begin marker */
 			st_readw(ft, &releaseLoopEnd);    /* end marker */
 
-			/* At least one known program generates an INST */
-			/* block with everything zeroed out (meaning    */
-			/* no Loops used).  In this case it should just */
-			/* be ignored.				        */
-			if (sustainLoopBegin == 0 && releaseLoopBegin == 0)
+			/* Required to ignore loops on playback if type
+			 * is 0 (NoLoop).  The other check is done for
+			 * historical reason and is probably not needed.
+			 */
+			if ((ft->loops[0].type == 0) ||
+			   (sustainLoopBegin == 0 && releaseLoopBegin == 0))
 				foundinstr = 0;
 			else
 				foundinstr = 1;
