@@ -31,40 +31,38 @@ typedef struct cdrstuff {
 	LONG	samples;	/* number of samples written */
 } *cdr_t;
 
-LONG rawread(P3(ft_t, LONG *, LONG));
-void rawwrite(P3(ft_t, LONG *, LONG));
-
 /*
  * Do anything required before you start reading samples.
  * Read file header. 
  *	Find out sampling rate, 
- *	size and style of samples, 
+ *	size and encoding of samples, 
  *	mono/stereo/quad.
  */
 
-void cdrstartread(ft) 
+int st_cdrstartread(ft) 
 ft_t ft;
 {
-
-	int     littlendian = 1;
-	char    *endptr;
+	int rc;
 
 	/* Needed because of rawread() */
-	rawstartread(ft);
+	rc = st_rawstartread(ft);
+	if (rc)
+	    return rc;
 
-	endptr = (char *) &littlendian;
 	/* CDR is in Big Endian format.  Swap whats read in on */
         /* Little Endian machines.                             */
-	if (*endptr)
+	if (ST_IS_LITTLEENDIAN)
 	{ 
 	    ft->swap = ft->swap ? 0 : 1;
 	}
 
 	ft->info.rate = 44100L;
-	ft->info.size = WORD;
-	ft->info.style = SIGN2;
+	ft->info.size = ST_SIZE_WORD;
+	ft->info.encoding = ST_ENCODING_SIGN2;
 	ft->info.channels = 2;
 	ft->comment = NULL;
+
+	return(ST_SUCCESS);
 }
 
 /*
@@ -74,53 +72,54 @@ ft_t ft;
  * Return number of samples read.
  */
 
-LONG cdrread(ft, buf, len) 
+LONG st_cdrread(ft, buf, len) 
 ft_t ft;
 LONG *buf, len;
 {
 
-	return rawread(ft, buf, len);
+	return st_rawread(ft, buf, len);
 }
 
 /*
  * Do anything required when you stop reading samples.  
  * Don't close input file! 
  */
-void cdrstopread(ft) 
+int st_cdrstopread(ft) 
 ft_t ft;
 {
 	/* Needed because of rawread() */
-	rawstopread(ft);
+	return st_rawstopread(ft);
 }
 
-void cdrstartwrite(ft) 
+int st_cdrstartwrite(ft) 
 ft_t ft;
 {
 	cdr_t cdr = (cdr_t) ft->priv;
+	int rc;
 
-	int     littlendian = 1;
-	char    *endptr;
-
-	endptr = (char *) &littlendian;
 	/* CDR is in Big Endian format.  Swap whats written out on */
 	/* Little Endian Machines.                                 */
-	if (*endptr) 
+	if (ST_IS_LITTLEENDIAN)
 	{
 	    ft->swap = ft->swap ? 0 : 1;
 	}
 
 	/* Needed because of rawwrite() */
-	rawstartwrite(ft);
+	rc = st_rawstartwrite(ft);
+	if (rc)
+	    return rc;
 
 	cdr->samples = 0;
 
 	ft->info.rate = 44100L;
-	ft->info.size = WORD;
-	ft->info.style = SIGN2;
+	ft->info.size = ST_SIZE_WORD;
+	ft->info.encoding = ST_ENCODING_SIGN2;
 	ft->info.channels = 2;
+
+	return(ST_SUCCESS);
 }
 
-void cdrwrite(ft, buf, len) 
+LONG st_cdrwrite(ft, buf, len) 
 ft_t ft;
 LONG *buf, len;
 {
@@ -128,7 +127,7 @@ LONG *buf, len;
 
 	cdr->samples += len;
 
-	rawwrite(ft, buf, len);
+	return st_rawwrite(ft, buf, len);
 }
 
 /*
@@ -136,24 +135,29 @@ LONG *buf, len;
  * samples.  We write -32768 for each sample to pad it out.
  */
 
-void cdrstopwrite(ft) 
+int st_cdrstopwrite(ft) 
 ft_t ft;
 {
 	cdr_t cdr = (cdr_t) ft->priv;
 	int padsamps = SECTORSIZE - (cdr->samples % SECTORSIZE);
 	short zero;
+	int rc;
 
 	/* Flush buffer before writing anything else */
-	rawstopwrite(ft);
+	rc = st_rawstopwrite(ft);
+
+	if (rc)
+	    return rc;
 
 	zero = 0;
 
 	if (padsamps != SECTORSIZE) 
 	{
 		while (padsamps > 0) {
-			wshort(ft, zero);
+			st_writew(ft, zero);
 			padsamps--;
 		}
 	}
+	return(ST_SUCCESS);
 }
 
