@@ -53,9 +53,6 @@
  */
 
 #include <stdlib.h> /* Harmless, and prototypes atof() etc. --dgc */
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
-#endif
 #include <math.h>
 #include <string.h>
 #include "st.h"
@@ -79,55 +76,10 @@ typedef struct flangerstuff {
 
 /* Private data for SKEL file */
 
-LONG flanger_clip24(l)
-LONG l;
-{
-	if (l >= ((LONG)1 << 24))
-		return ((LONG)1 << 24) - 1;
-	else if (l <= -((LONG)1 << 24))
-		return -((LONG)1 << 24) + 1;
-	else
-		return l;
-}
-
-/* This was very painful.  We need a sine library. */
-
-void flanger_sine(buf, len, depth)
-int *buf;
-long len;
-long depth;
-{
-	long i;
-	double val;
-
-	for (i = 0; i < len; i++) {
-		val = sin((double)i/(double)len * 2.0 * M_PI);
-		buf[i] = (int) ((1.0 + val) * depth / 2.0);
-	}
-}
-
-void flanger_triangle(buf, len, depth)
-int *buf;
-long len;
-long depth;
-{
-	long i;
-	double val;
-
-	for (i = 0; i < len / 2; i++) {
-		val = i * 2.0 / len;
-		buf[i] = (int) (val * depth);
-	}
-	for (i = len / 2; i < len ; i++) {
-		val = (len - i) * 2.0 / len;
-		buf[i] = (int) (val * depth);
-	}
-}
-
 /*
  * Process options
  */
-void flanger_getopts(effp, n, argv) 
+int st_flanger_getopts(effp, n, argv) 
 eff_t effp;
 int n;
 char **argv;
@@ -135,7 +87,10 @@ char **argv;
 	flanger_t flanger = (flanger_t) effp->priv;
 
 	if (!((n == 5) || (n == 6)))
-	    fail("Usage: flanger gain-in gain-out delay decay speed [ -s | -t ]");
+	{
+	    st_fail("Usage: flanger gain-in gain-out delay decay speed [ -s | -t ]");
+	    return (ST_EOF);
+	}
 
 	sscanf(argv[0], "%f", &flanger->in_gain);
 	sscanf(argv[1], "%f", &flanger->out_gain);
@@ -149,14 +104,18 @@ char **argv;
 		else if ( ! strcmp(argv[5], "-t"))
 			flanger->modulation = MOD_TRIANGLE;
 		else
-	    		fail("Usage: flanger gain-in gain-out delay decay speed [ -s | -t ]");
+		{
+	    		st_fail("Usage: flanger gain-in gain-out delay decay speed [ -s | -t ]");
+			return (ST_EOF);
+		}
 	}
+	return (ST_SUCCESS);
 }
 
 /*
  * Prepare for processing.
  */
-void flanger_start(effp)
+int st_flanger_start(effp)
 eff_t effp;
 {
 	flanger_t flanger = (flanger_t) effp->priv;
@@ -165,49 +124,85 @@ eff_t effp;
 	flanger->maxsamples = flanger->delay * effp->ininfo.rate / 1000.0;
 
 	if ( flanger->in_gain < 0.0 )
-	    fail("flanger: gain-in must be positive!\n");
+	{
+	    st_fail("flanger: gain-in must be positive!\n");
+	    return (ST_EOF);
+	}
 	if ( flanger->in_gain > 1.0 )
-	    fail("flanger: gain-in must be less than 1.0!\n");
+	{
+	    st_fail("flanger: gain-in must be less than 1.0!\n");
+	    return (ST_EOF);
+	}
 	if ( flanger->out_gain < 0.0 )
-	    fail("flanger: gain-out must be positive!\n");
+	{
+	    st_fail("flanger: gain-out must be positive!\n");
+	    return (ST_EOF);
+	}
 	if ( flanger->delay < 0.0 )
-	    fail("flanger: delay must be positive!\n");
+	{
+	    st_fail("flanger: delay must be positive!\n");
+	    return (ST_EOF);
+	}
 	if ( flanger->delay > 5.0 )
-	    fail("flanger: delay must be less than 5.0 msec!\n");
+	{
+	    st_fail("flanger: delay must be less than 5.0 msec!\n");
+	    return (ST_EOF);
+	}
 	if ( flanger->speed < 0.1 )
-	    fail("flanger: speed must be more than 0.1 Hz!\n");
+	{
+	    st_fail("flanger: speed must be more than 0.1 Hz!\n");
+	    return (ST_EOF);
+	}
 	if ( flanger->speed > 2.0 )
-	    fail("flanger: speed must be less than 2.0 Hz!\n");
+	{
+	    st_fail("flanger: speed must be less than 2.0 Hz!\n");
+	    return (ST_EOF);
+	}
 	if ( flanger->decay < 0.0 )
-	    fail("flanger: decay must be positive!\n" );
+	{
+	    st_fail("flanger: decay must be positive!\n" );
+	    return (ST_EOF);
+	}
 	if ( flanger->decay > 1.0 )
-	    fail("flanger: decay must be less that 1.0!\n" );
+	{
+	    st_fail("flanger: decay must be less that 1.0!\n" );
+	    return (ST_EOF);
+	}
 	/* Be nice and check the hint with warning, if... */
 	if ( flanger->in_gain * ( 1.0 + flanger->decay ) > 1.0 / flanger->out_gain )
-		warn("flanger: warning >>> gain-out can cause saturation or clipping of output <<<");
+		st_warn("flanger: warning >>> gain-out can cause saturation or clipping of output <<<");
 
 	flanger->length = effp->ininfo.rate / flanger->speed;
 
 	if (! (flanger->flangerbuf = 
 		(double *) malloc(sizeof (double) * flanger->maxsamples)))
-		fail("flanger: Cannot malloc %d bytes!\n", 
+	{
+		st_fail("flanger: Cannot malloc %d bytes!\n", 
 			sizeof(double) * flanger->maxsamples);
+		return (ST_EOF);
+	}
 	for ( i = 0; i < flanger->maxsamples; i++ )
 		flanger->flangerbuf[i] = 0.0;
 	if (! (flanger->lookup_tab = 
 		(int *) malloc(sizeof (int) * flanger->length)))
-		fail("flanger: Cannot malloc %d bytes!\n", 
+	{
+		st_fail("flanger: Cannot malloc %d bytes!\n", 
 			sizeof(int) * flanger->length);
+		return(ST_EOF);
+	}
 
 	if ( flanger->modulation == MOD_SINE )
-		flanger_sine(flanger->lookup_tab, flanger->length, 
+		st_sine(flanger->lookup_tab, flanger->length, 
+			flanger->maxsamples - 1,
 			flanger->maxsamples - 1);
 	else
-		flanger_triangle(flanger->lookup_tab, flanger->length, 
+		st_triangle(flanger->lookup_tab, flanger->length, 
+			(flanger->maxsamples - 1) * 2, 
 			flanger->maxsamples - 1);
 	flanger->counter = 0;
 	flanger->phase = 0;
 	flanger->fade_out = flanger->maxsamples;
+	return (ST_SUCCESS);
 }
 
 /*
@@ -215,10 +210,10 @@ eff_t effp;
  * Return number of samples processed.
  */
 
-void flanger_flow(effp, ibuf, obuf, isamp, osamp)
+int st_flanger_flow(effp, ibuf, obuf, isamp, osamp)
 eff_t effp;
 LONG *ibuf, *obuf;
-int *isamp, *osamp;
+LONG *isamp, *osamp;
 {
 	flanger_t flanger = (flanger_t) effp->priv;
 	int len, done;
@@ -237,7 +232,7 @@ int *isamp, *osamp;
 	flanger->maxsamples] * flanger->decay;
 		/* Adjust the output volume and size to 24 bit */
 		d_out = d_out * flanger->out_gain;
-		out = flanger_clip24((LONG) d_out);
+		out = st_clip24((LONG) d_out);
 		*obuf++ = out * 256;
 		/* Mix decay of delay and input */
 		flanger->flangerbuf[flanger->counter] = d_in;
@@ -246,15 +241,16 @@ int *isamp, *osamp;
 		flanger->phase  = ( flanger->phase + 1 ) % flanger->length;
 	}
 	/* processed all samples */
+	return (ST_SUCCESS);
 }
 
 /*
  * Drain out reverb lines. 
  */
-void flanger_drain(effp, obuf, osamp)
+int st_flanger_drain(effp, obuf, osamp)
 eff_t effp;
 LONG *obuf;
-int *osamp;
+LONG *osamp;
 {
 	flanger_t flanger = (flanger_t) effp->priv;
 	int done;
@@ -272,7 +268,7 @@ int *osamp;
 	flanger->maxsamples] * flanger->decay;
 		/* Adjust the output volume and size to 24 bit */
 		d_out = d_out * flanger->out_gain;
-		out = flanger_clip24((LONG) d_out);
+		out = st_clip24((LONG) d_out);
 		*obuf++ = out * 256;
 		/* Mix decay of delay and input */
 		flanger->flangerbuf[flanger->counter] = d_in;
@@ -284,12 +280,13 @@ int *osamp;
 	}
 	/* samples playd, it remains */
 	*osamp = done;
+	return (ST_SUCCESS);
 }
 
 /*
  * Clean up flanger effect.
  */
-void flanger_stop(effp)
+int st_flanger_stop(effp)
 eff_t effp;
 {
 	flanger_t flanger = (flanger_t) effp->priv;
@@ -298,5 +295,5 @@ eff_t effp;
 	flanger->flangerbuf = (double *) -1;   /* guaranteed core dump */
 	free((char *) flanger->lookup_tab);
 	flanger->lookup_tab = (int *) -1;   /* guaranteed core dump */
+	return (ST_SUCCESS);
 }
-
