@@ -505,6 +505,18 @@ extern int st_echos_flow();
 extern int st_echos_drain();
 extern int st_echos_stop();
 
+extern int st_earwax_getopts();
+extern int st_earwax_start();
+extern int st_earwax_flow();
+extern int st_earwax_drain();
+extern int st_earwax_stop();
+
+extern int st_fade_getopts();
+extern int st_fade_start();
+extern int st_fade_flow();
+extern int st_fade_drain();
+extern int st_fade_stop();
+
 extern int st_filter_getopts();
 extern int st_filter_start();
 extern int st_filter_flow();
@@ -673,12 +685,18 @@ st_effect_t st_effects[] = {
 	{"deemph", ST_EFF_MCHAN,
 	        st_deemph_getopts, st_deemph_start, st_deemph_flow,
 	        st_null_drain, st_deemph_stop},
+	{"earwax", ST_EFF_MCHAN, 
+		st_earwax_getopts, st_earwax_start, st_earwax_flow, 
+		st_earwax_drain, st_earwax_stop},
 	{"echo", 0, 
 		st_echo_getopts, st_echo_start, st_echo_flow, 
 		st_echo_drain, st_echo_stop},
 	{"echos", 0, 
 		st_echos_getopts, st_echos_start, st_echos_flow,
 	        st_echos_drain, st_echos_stop},
+	{"fade", ST_EFF_MCHAN, 
+		st_fade_getopts, st_fade_start, st_fade_flow,
+	        st_fade_drain, st_fade_stop},
 	{ "filter", 0,
 	    	st_filter_getopts, st_filter_start, st_filter_flow,
 		st_filter_drain, st_filter_stop},
