@@ -56,9 +56,6 @@
  */
 
 #include <stdlib.h> /* Harmless, and prototypes atof() etc. --dgc */
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
-#endif
 #include <math.h>
 #include <string.h>
 #include "st.h"
@@ -80,57 +77,10 @@ typedef struct phaserstuff {
 	long	maxsamples, fade_out;
 } *phaser_t;
 
-/* Private data for SKEL file */
-
-LONG phaser_clip24(l)
-LONG l;
-{
-	if (l >= ((LONG)1 << 24))
-		return ((LONG)1 << 24) - 1;
-	else if (l <= -((LONG)1 << 24))
-		return -((LONG)1 << 24) + 1;
-	else
-		return l;
-}
-
-/* This was very painful.  We need a sine library. */
-
-void phaser_sine(buf, len, depth)
-int *buf;
-long len;
-long depth;
-{
-	long i;
-	double val;
-
-	for (i = 0; i < len; i++) {
-		val = sin((double)i/(double)len * 2.0 * M_PI);
-		buf[i] = (int) ((1.0 + val) * depth / 2.0);
-	}
-}
-
-void phaser_triangle(buf, len, depth)
-int *buf;
-long len;
-long depth;
-{
-	long i;
-	double val;
-
-	for (i = 0; i < len / 2; i++) {
-		val = i * 2.0 / len;
-		buf[i] = (int) (val * depth);
-	}
-	for (i = len / 2; i < len ; i++) {
-		val = (len - i) * 2.0 / len;
-		buf[i] = (int) (val * depth);
-	}
-}
-
 /*
  * Process options
  */
-void phaser_getopts(effp, n, argv) 
+int st_phaser_getopts(effp, n, argv) 
 eff_t effp;
 int n;
 char **argv;
@@ -138,7 +88,10 @@ char **argv;
 	phaser_t phaser = (phaser_t) effp->priv;
 
 	if (!((n == 5) || (n == 6)))
-	    fail("Usage: phaser gain-in gain-out delay decay speed [ -s | -t ]");
+	{
+	    st_fail("Usage: phaser gain-in gain-out delay decay speed [ -s | -t ]");
+	    return (ST_EOF);
+	}
 
 	sscanf(argv[0], "%f", &phaser->in_gain);
 	sscanf(argv[1], "%f", &phaser->out_gain);
@@ -152,14 +105,18 @@ char **argv;
 		else if ( ! strcmp(argv[5], "-t"))
 			phaser->modulation = MOD_TRIANGLE;
 		else
-	    		fail("Usage: phaser gain-in gain-out delay decay speed [ -s | -t ]");
+		{
+	    		st_fail("Usage: phaser gain-in gain-out delay decay speed [ -s | -t ]");
+			return (ST_EOF);
+		}
 	}
+	return (ST_SUCCESS);
 }
 
 /*
  * Prepare for processing.
  */
-void phaser_start(effp)
+int st_phaser_start(effp)
 eff_t effp;
 {
 	phaser_t phaser = (phaser_t) effp->priv;
@@ -168,45 +125,72 @@ eff_t effp;
 	phaser->maxsamples = phaser->delay * effp->ininfo.rate / 1000.0;
 
 	if ( phaser->delay < 0.0 )
-	    fail("phaser: delay must be positive!\n");
+	{
+	    st_fail("phaser: delay must be positive!\n");
+	    return (ST_EOF);
+	}
 	if ( phaser->delay > 5.0 )
-	    fail("phaser: delay must be less than 5.0 msec!\n");
+	{
+	    st_fail("phaser: delay must be less than 5.0 msec!\n");
+	    return (ST_EOF);
+	}
 	if ( phaser->speed < 0.1 )
-	    fail("phaser: speed must be more than 0.1 Hz!\n");
+	{
+	    st_fail("phaser: speed must be more than 0.1 Hz!\n");
+	    return (ST_EOF);
+	}
 	if ( phaser->speed > 2.0 )
-	    fail("phaser: speed must be less than 2.0 Hz!\n");
+	{
+	    st_fail("phaser: speed must be less than 2.0 Hz!\n");
+	    return (ST_EOF);
+	}
 	if ( phaser->decay < 0.0 )
-	    fail("phaser: decay must be positive!\n" );
+	{
+	    st_fail("phaser: decay must be positive!\n" );
+	    return (ST_EOF);
+	}
 	if ( phaser->decay >= 1.0 )
-	    fail("phaser: decay must be less that 1.0!\n" );
+	{
+	    st_fail("phaser: decay must be less that 1.0!\n" );
+	    return (ST_EOF);
+	}
 	/* Be nice and check the hint with warning, if... */
 	if ( phaser->in_gain > ( 1.0 - phaser->decay * phaser->decay ) )
-		warn("phaser: warning >>> gain-in can cause saturation or clipping of output <<<");
+		st_warn("phaser: warning >>> gain-in can cause saturation or clipping of output <<<");
 	if ( phaser->in_gain / ( 1.0 - phaser->decay ) > 1.0 / phaser->out_gain )
-		warn("phaser: warning >>> gain-out can cause saturation or clipping of output <<<");
+		st_warn("phaser: warning >>> gain-out can cause saturation or clipping of output <<<");
 
 	phaser->length = effp->ininfo.rate / phaser->speed;
 
 	if (! (phaser->phaserbuf = 
 		(double *) malloc(sizeof (double) * phaser->maxsamples)))
-		fail("phaser: Cannot malloc %d bytes!\n", 
+	{
+		st_fail("phaser: Cannot malloc %d bytes!\n", 
 			sizeof(double) * phaser->maxsamples);
+		return (ST_EOF);
+	}
 	for ( i = 0; i < phaser->maxsamples; i++ )
 		phaser->phaserbuf[i] = 0.0;
 	if (! (phaser->lookup_tab = 
 		(int *) malloc(sizeof (int) * phaser->length)))
-		fail("phaser: Cannot malloc %d bytes!\n", 
+	{
+		st_fail("phaser: Cannot malloc %d bytes!\n", 
 			sizeof(int) * phaser->length);
+		return (ST_EOF);
+	}
 
 	if ( phaser->modulation == MOD_SINE )
-		phaser_sine(phaser->lookup_tab, phaser->length, 
+		st_sine(phaser->lookup_tab, phaser->length, 
+			phaser->maxsamples - 1,
 			phaser->maxsamples - 1);
 	else
-		phaser_triangle(phaser->lookup_tab, phaser->length, 
+		st_triangle(phaser->lookup_tab, phaser->length, 
+			(phaser->maxsamples - 1) * 2,
 			phaser->maxsamples - 1);
 	phaser->counter = 0;
 	phaser->phase = 0;
 	phaser->fade_out = phaser->maxsamples;
+	return (ST_SUCCESS);
 }
 
 /*
@@ -214,10 +198,10 @@ eff_t effp;
  * Return number of samples processed.
  */
 
-void phaser_flow(effp, ibuf, obuf, isamp, osamp)
+int st_phaser_flow(effp, ibuf, obuf, isamp, osamp)
 eff_t effp;
 LONG *ibuf, *obuf;
-int *isamp, *osamp;
+LONG *isamp, *osamp;
 {
 	phaser_t phaser = (phaser_t) effp->priv;
 	int len, done;
@@ -236,7 +220,7 @@ int *isamp, *osamp;
 	phaser->maxsamples] * phaser->decay * -1.0;
 		/* Adjust the output volume and size to 24 bit */
 		d_out = d_in * phaser->out_gain;
-		out = phaser_clip24((LONG) d_out);
+		out = st_clip24((LONG) d_out);
 		*obuf++ = out * 256;
 		/* Mix decay of delay and input */
 		phaser->phaserbuf[phaser->counter] = d_in;
@@ -245,15 +229,16 @@ int *isamp, *osamp;
 		phaser->phase  = ( phaser->phase + 1 ) % phaser->length;
 	}
 	/* processed all samples */
+	return (ST_SUCCESS);
 }
 
 /*
  * Drain out reverb lines. 
  */
-void phaser_drain(effp, obuf, osamp)
+int st_phaser_drain(effp, obuf, osamp)
 eff_t effp;
 LONG *obuf;
-int *osamp;
+LONG *osamp;
 {
 	phaser_t phaser = (phaser_t) effp->priv;
 	int done;
@@ -271,7 +256,7 @@ int *osamp;
 	phaser->maxsamples] * phaser->decay * -1.0;
 		/* Adjust the output volume and size to 24 bit */
 		d_out = d_in * phaser->out_gain;
-		out = phaser_clip24((LONG) d_out);
+		out = st_clip24((LONG) d_out);
 		*obuf++ = out * 256;
 		/* Mix decay of delay and input */
 		phaser->phaserbuf[phaser->counter] = d_in;
@@ -283,12 +268,13 @@ int *osamp;
 	}
 	/* samples playd, it remains */
 	*osamp = done;
+	return (ST_SUCCESS);
 }
 
 /*
  * Clean up phaser effect.
  */
-void phaser_stop(effp)
+int st_phaser_stop(effp)
 eff_t effp;
 {
 	phaser_t phaser = (phaser_t) effp->priv;
@@ -297,5 +283,6 @@ eff_t effp;
 	phaser->phaserbuf = (double *) -1;   /* guaranteed core dump */
 	free((char *) phaser->lookup_tab);
 	phaser->lookup_tab = (int *) -1;   /* guaranteed core dump */
+	return (ST_SUCCESS);
 }
 
