@@ -27,8 +27,6 @@
  */ 
 
 #include "st.h"
-#include "version.h"
-#include "patchlvl.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>		/* for malloc() */
@@ -473,7 +471,7 @@ static void process(P0) {
 #if	defined(DUMB_FILESYSTEM)
 	outformat.seekable = 0;
 #else
-	outformat.seekable  = (filetype(fileno(informat.fp)) == S_IFREG);
+	outformat.seekable  = (filetype(fileno(outformat.fp)) == S_IFREG);
 #endif
 
 	st_copyformat(&informat, &outformat);
