@@ -90,8 +90,8 @@ ft_t ft;
 		    ft->info.encoding = ST_ENCODING_ULAW;
 		}
 	    }
-	    if (strncmp(buf, "sample_rate", 11) == 0 &&
-		ft->info.rate == -1)
+	    if (strncmp(buf, "sample_rate ", 12) == 0 &&
+		ft->info.rate == 0)
 	    {
 #ifdef __alpha__
 		sscanf(buf, "%s %s %d", fldname, fldtype, &ft->info.rate);
